# econometrics_tools_wagner

Personal Python module for econometrics and machine learning utilities.

## Functions
- vif
- ols
- boxcox_transform
- plot_roc
- plot_multiple_roc
- plot_precision_recall